Skip to content

Provides utilities for working with Google APIs https://developers.google.com/apis-explorer. This includes functions and classes for handling common credential types and for preparing, executing, and processing HTTP requests.

Author

Maintainer: Jennifer Bryan jenny@posit.co (ORCID)

Authors:

Other contributors:

  • Google Inc [copyright holder]

  • Posit Software, PBC [copyright holder, funder]