These functions give access to the most recent response processed by
response_process(..., remember = TRUE). They can be
useful for post mortem analysis of puzzling or failed API interactions.
Value
gargle_last_response()returns the most recenthttr::response()object.gargle_last_content()returns the parsed JSON content from the most recent response or an empty list if unavailable.